@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -116,7 +116,7 @@ class Certificate(object):
                 self.logical_name,
             )
 
-        self.cfn_resource = AcmCert(self.logical_name, **props)
+        self.cfn_resource = AcmCert(f"{self.logical_name}AcmCert", **props)
 
 
 def define_acm_certs(new_resources, dns_settings, root_stack):
