@@ -1,6 +1,6 @@
-﻿#  -*- coding: utf-8 -*-
+#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -21,11 +21,16 @@ Module to define the ComposeX Resources into a simple object to make it easier t
 
 from copy import deepcopy
 
-from troposphere import Output, Parameter
-from troposphere import Ref, GetAtt
+from troposphere import Output, Parameter, Export
+from troposphere import Ref, GetAtt, Sub, If
+from troposphere import AWS_STACK_NAME
 from troposphere.ecs import Environment
 
+
 from ecs_composex.common import LOG, NONALPHANUM, keyisset, keypresent
+from ecs_composex.common.ecs_composex import CFN_EXPORT_DELIMITER as DELIM
+from ecs_composex.common.cfn_conditions import USE_STACK_NAME_CON_T
+from ecs_composex.common.cfn_params import ROOT_STACK_NAME
 
 
 def set_resources(settings, resource_class, res_key):
@@ -116,6 +121,7 @@ class XResource(object):
         self.attributes_outputs = {}
         self.families_targets = []
         self.families_scaling = []
+        self.subnets_override = None
         self.arn_attr = None
         self.arn_parameter = None
         self.arn_value = None
@@ -291,10 +297,32 @@ class XResource(object):
                     definition[2],
                 )
             name = NONALPHANUM.sub("", definition[0])
+            if len(definition) == 5 and definition[4]:
+                LOG.debug(f"Adding portback output for {self.name}")
+                export = Export(
+                    If(
+                        USE_STACK_NAME_CON_T,
+                        Sub(
+                            f"${{{AWS_STACK_NAME}}}{DELIM}{self.name}{DELIM}{definition[4]}"
+                        ),
+                        Sub(
+                            f"${{{ROOT_STACK_NAME.title}}}{DELIM}{self.name}{DELIM}{definition[4]}"
+                        ),
+                    )
+                )
+            else:
+                export = Export(
+                    If(
+                        USE_STACK_NAME_CON_T,
+                        Sub(f"${{{AWS_STACK_NAME}}}{DELIM}{name}"),
+                        Sub(f"${{{ROOT_STACK_NAME.title}}}{DELIM}{name}"),
+                    )
+                )
             self.attributes_outputs[output_prop_name] = {
                 "Name": name,
-                "Output": Output(name, Value=value),
+                "Output": Output(name, Value=value, Export=export),
             }
+
         for attr in self.attributes_outputs.values():
             self.outputs.append(attr["Output"])
 
@@ -360,3 +388,11 @@ class XResource(object):
                 self.attributes_outputs.keys(),
             )
         return GetAtt(stack_name, f"Outputs.{self.attributes_outputs[title]['Name']}")
+
+    def set_override_subnets(self):
+        if (
+            self.settings
+            and keyisset("Subnets", self.settings)
+            and hasattr(self, "subnets_param")
+        ):
+            self.subnets_override = self.settings["Subnets"]
