@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -16,16 +16,13 @@
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import re
+from os import path
 from copy import deepcopy
 from json import dumps
 
-from troposphere import (
-    AWS_NO_VALUE,
-    AWS_REGION,
-    AWS_STACK_NAME,
-)
+from troposphere import AWS_NO_VALUE, AWS_REGION, AWS_STACK_NAME, AWS_PARTITION
 from troposphere import Parameter, Tags
-from troposphere import Sub, Ref, GetAtt, ImportValue, Join
+from troposphere import Sub, Ref, GetAtt, ImportValue, Join, If
 from troposphere.ecs import (
     HealthCheck,
     Environment,
@@ -33,11 +30,16 @@ from troposphere.ecs import (
     LogConfiguration,
     ContainerDefinition,
     TaskDefinition,
+    EnvironmentFile,
+    RepositoryCredentials,
 )
-from troposphere.iam import Policy
+from troposphere.iam import Policy, PolicyType
+from troposphere.codeguruprofiler import ProfilingGroup
 
-from ecs_composex.common import NONALPHANUM, LOG
+from ecs_composex.resources_import import import_record_properties
+from ecs_composex.common import NONALPHANUM, LOG, FILE_PREFIX
 from ecs_composex.common import keyisset, keypresent
+from ecs_composex.common.files import upload_file
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME
 from ecs_composex.common.compose_volumes import (
     ComposeVolume,
@@ -50,9 +52,15 @@ from ecs_composex.ecs.docker_tools import (
     set_memory_to_mb,
 )
 from ecs_composex.ecs.ecs_iam import add_service_roles
-from ecs_composex.ecs.ecs_params import AWS_XRAY_IMAGE
-from ecs_composex.ecs.ecs_params import LOG_GROUP_RETENTION
-from ecs_composex.ecs.ecs_params import NETWORK_MODE, EXEC_ROLE_T, TASK_ROLE_T, TASK_T
+from ecs_composex.ecs.ecs_params import (
+    AWS_XRAY_IMAGE,
+    LOG_GROUP_RETENTION,
+    NETWORK_MODE,
+    EXEC_ROLE_T,
+    TASK_ROLE_T,
+    TASK_T,
+)
+from ecs_composex.ecs.ecs_conditions import USE_FARGATE_CON_T
 from ecs_composex.iam import define_iam_policy, add_role_boundaries
 from ecs_composex.secrets.compose_secrets import (
     ComposeSecret,
@@ -186,7 +194,11 @@ def define_ingress_mappings(service_ports):
     """
     ingress_mappings = {}
     for port in service_ports:
-        if port["target"] not in ingress_mappings.keys():
+        if not keyisset("target", port):
+            raise KeyError("The ports must always at least define the target.")
+        if not keyisset("published", port):
+            port["published"] = port["target"]
+        if not port["target"] in ingress_mappings.keys():
             ingress_mappings[port["target"]] = [port["published"]]
         elif (
             port["target"] in ingress_mappings.keys()
@@ -284,6 +296,7 @@ class ComposeService(object):
         ("x-xray", bool),
         ("x-scaling", dict),
         ("x-network", dict),
+        ("x-codeguru-profiler", (str, bool, dict)),
     ]
 
     ecs_plugin_aws_keys = [
@@ -291,6 +304,7 @@ class ComposeService(object):
         ("x-aws-policies", list),
         ("x-aws-autoscaling", dict),
         ("x-aws-pull_credentials", str),
+        ("x-aws-logs_retention", int),
     ]
 
     def __init__(self, name, definition, volumes=None, secrets=None):
@@ -331,13 +345,17 @@ class ComposeService(object):
         self.x_network = set_else_none("x-network", self.definition, None, False)
         self.x_iam = set_else_none("x-iam", self.definition)
         self.x_logging = {"RetentionInDays": 14, "CreateLogGroup": True}
-
+        self.x_repo_credentials = None
         self.import_x_aws_settings()
         self.networks = {}
         self.replicas = 1
         self.container = None
         self.volumes = []
         self.secrets = []
+        self.env_files = []
+        self.code_profiler = None
+        self.set_env_files()
+        self.set_code_profiler()
         self.environment = set_else_none("environment", self.definition, None, False)
         self.cfn_environment = (
             import_env_variables(self.environment)
@@ -376,27 +394,41 @@ class ComposeService(object):
 
         self.map_volumes(volumes)
         self.map_secrets(secrets)
+        self.define_families()
         self.set_service_deploy()
         self.set_container_definition()
         self.set_networks()
 
+    def define_port_mappings(self):
+        """
+        Method to determine the list of port mappings to use for either AWS VPC deployments or else (bridge etc).
+        Not in use atm as AWS VPC is made mandatory
+        """
+        ec2_mappings = []
+        aws_vpc_mappings = []
+        for c_port, h_ports in self.ingress_mappings.items():
+            for port in h_ports:
+                ec2_mappings.append(PortMapping(ContainerPort=c_port, HostPort=port))
+        for port in self.ingress_mappings.keys():
+            aws_vpc_mappings = [
+                PortMapping(ContainerPort=port, HostPort=port)
+                for port in self.ingress_mappings.keys()
+            ]
+        return aws_vpc_mappings, ec2_mappings
+
     def set_container_definition(self):
         """
         Function to define the container definition matching the service definition
         """
         secrets = [secret for secrets in self.secrets for secret in secrets.ecs_secret]
+        ports_mappings = self.define_port_mappings()
         self.container_definition = ContainerDefinition(
             Image=Ref(self.image_param),
             Name=self.name,
             Cpu=self.cpu_amount if self.cpu_amount else Ref(AWS_NO_VALUE),
             Memory=self.mem_alloc if self.mem_alloc else Ref(AWS_NO_VALUE),
             MemoryReservation=self.mem_resa if self.mem_resa else Ref(AWS_NO_VALUE),
-            PortMappings=[
-                PortMapping(ContainerPort=port, HostPort=port)
-                for port in self.ingress_mappings.keys()
-            ]
-            if self.ports
-            else Ref(AWS_NO_VALUE),
+            PortMappings=ports_mappings[0] if self.ports else Ref(AWS_NO_VALUE),
             Environment=self.cfn_environment,
             LogConfiguration=LogConfiguration(
                 LogDriver="awslogs",
@@ -414,6 +446,61 @@ class ComposeService(object):
         )
         self.container_parameters.update({self.image_param.title: self.image})
 
+    def set_code_profiler(self):
+        """
+        Method to define the code guru profiler for the service
+        :return:
+        """
+        profiler_key = "x-codeguru-profiler"
+        if not keypresent(profiler_key, self.definition):
+            return
+        if isinstance(self.definition[profiler_key], str):
+            self.cfn_environment.append(
+                Environment(
+                    Name="AWS_CODEGURU_PROFILER_GROUP_ARN",
+                    Value=self.definition[profiler_key],
+                )
+            )
+        elif (
+            isinstance(self.definition[profiler_key], bool)
+            and self.definition[profiler_key]
+        ):
+            self.code_profiler = ProfilingGroup(
+                f"ProfilingGroup{self.logical_name}",
+                ProfilingGroupName=Sub(f"${{{AWS_STACK_NAME}}}-{self.name}"),
+            )
+        elif isinstance(self.definition[profiler_key], dict):
+            props = import_record_properties(
+                self.definition[profiler_key], ProfilingGroup
+            )
+            self.code_profiler = ProfilingGroup(
+                f"ProfilingGroup{self.logical_name}", **props
+            )
+
+    def set_env_files(self):
+        """
+        Method to list all the env files and check the files are found and available.
+        """
+        env_file_key = "env_file"
+        if not keyisset(env_file_key, self.definition):
+            return
+        if isinstance(self.definition[env_file_key], str):
+            file_path = self.definition[env_file_key]
+            if not path.exists(path.abspath(file_path)):
+                raise FileNotFoundError("No file found at", path.abspath(file_path))
+            self.env_files.append(path.abspath(file_path))
+        elif isinstance(self.definition[env_file_key], list):
+            for file_path in self.definition[env_file_key]:
+                if not isinstance(file_path, str):
+                    raise TypeError(
+                        "Files in the env_file is supposed to be a list of paths to files (str). Got",
+                        type(file_path),
+                    )
+                if not path.exists(path.abspath(file_path)):
+                    raise FileNotFoundError("No file found at", path.abspath(file_path))
+                self.env_files.append(path.abspath(file_path))
+        LOG.debug(self.env_files)
+
     def set_networks(self):
         if not keyisset("networks", self.definition):
             return
@@ -454,12 +541,21 @@ class ComposeService(object):
             self.x_iam["ManagedPolicyArns"] += self.definition[key]
             LOG.info(f"Merged {key} definition")
 
+    def set_x_credentials_secret(self, key):
+        """
+        Method that will set the secret associated to the service to retrieve the docker image if defined through
+        x-aws-pull_credentials
+        """
+        if not keyisset(key, self.definition):
+            return
+        self.x_repo_credentials = self.definition[key]
+
     def import_x_aws_settings(self):
         aws_keys = [
             ("x-aws-role", dict, self.merge_x_aws_role),
             ("x-aws-policies", list, self.merge_x_policies),
             ("x-aws-autoscaling", dict, None),
-            ("x-aws-pull_credentials", str, None),
+            ("x-aws-pull_credentials", str, self.set_x_credentials_secret),
         ]
         for setting in aws_keys:
             if keyisset(setting[0], self.definition) and not isinstance(
@@ -480,6 +576,19 @@ class ComposeService(object):
         """
         if keyisset("x-logging", self.definition):
             self.x_logging = self.definition["x-logging"]
+        if keyisset("x-aws-logs_retention", self.definition) and keyisset(
+            "RetentionInDays", self.x_logging
+        ):
+            self.x_logging["RetentionInDays"] = max(
+                int(self.definition["x-aws-logs_retention"]),
+                int(self.x_logging["RetentionInDays"]),
+            )
+        elif keyisset("x-aws-logs_retention", self.definition) and not keyisset(
+            "RetentionInDays", self.x_logging
+        ):
+            self.x_logging["RetentionInDays"] = int(
+                self.definition["x-aws-logs_retention"]
+            )
 
     def map_volumes(self, volumes=None):
         """
@@ -643,16 +752,22 @@ class ComposeService(object):
                 )
             self.container_start_condition = deployment[labels][depends_key]
 
-    def define_families(self, deployment):
+    def define_families(self):
         """
         Function to assign the service to a family / families
         :param deployment:
         :return:
         """
+        deploy = "deploy"
         labels = "labels"
         ecs_task_family = "ecs.task.family"
-        if keyisset(labels, deployment) and keyisset(
-            ecs_task_family, deployment[labels]
+        deployment = {}
+        if keyisset(deploy, self.definition):
+            deployment = self.definition[deploy]
+        if (
+            deployment
+            and keyisset(labels, deployment)
+            and keyisset(ecs_task_family, deployment[labels])
         ):
             if isinstance(deployment[labels][ecs_task_family], str):
                 self.families = deployment[labels][ecs_task_family].split(",")
@@ -673,7 +788,6 @@ class ComposeService(object):
         deploy = "deploy"
         if not keyisset("deploy", self.definition):
             return
-        self.define_families(self.definition[deploy])
         self.set_compute_resources(self.definition[deploy])
         self.set_replicas(self.definition[deploy])
         self.define_start_condition(self.definition[deploy])
@@ -820,6 +934,43 @@ def handle_iam_boundary(config, key, new_value):
     config[key] = define_iam_policy(new_value)
 
 
+def identify_repo_credentials_secret(settings, task, secret_name):
+    """
+    Function to identify the secret_arn
+    :param settings:
+    :param ComposeFamily task:
+    :param secret_name:
+    :return:
+    """
+    secret_arn = None
+    for secret in settings.secrets:
+        if secret.name == secret_name:
+            secret_arn = secret.arn
+            if secret_name not in [s.name for s in settings.secrets]:
+                raise KeyError(
+                    f"secret {secret_name} was not found in the defined secrets",
+                    [s.name for s in settings.secrets],
+                )
+            if secret.kms_key_arn:
+                task.exec_role.Policies.append(
+                    Policy(
+                        PolicyName="RepositoryCredsKmsKeyAccess",
+                        PolicyDocument={
+                            "Version": "2012-10-17",
+                            "Statement": [
+                                {
+                                    "Effect": "Allow",
+                                    "Action": ["kms:Decrypt"],
+                                    "Resource": [secret.kms_key_arn],
+                                }
+                            ],
+                        },
+                    )
+                )
+            return secret_arn
+    return None
+
+
 class ComposeFamily(object):
     """
     Class to group services logically to create the final ECS Service
@@ -842,6 +993,8 @@ class ComposeFamily(object):
         self.task_definition = None
         self.service_definition = None
         self.service_config = None
+        self.exec_role = None
+        self.task_role = None
         self.scalable_target = None
         self.ecs_service = None
         self.task_logging_options = {}
@@ -1178,7 +1331,7 @@ class ComposeFamily(object):
             logging_def.Options.update(self.task_logging_options)
 
     def init_task_definition(self):
-        add_service_roles(self.template)
+        add_service_roles(self)
         self.set_task_compute_parameter()
         self.set_task_definition()
         self.refresh_container_logging_definition()
@@ -1198,3 +1351,186 @@ class ComposeFamily(object):
                 LOG.info(
                     f"Set {network.subnet_name} as {APP_SUBNETS.title} for {self.name}"
                 )
+
+    def set_codeguru_principals(self, service):
+        """
+        Method to set codeguru principal for profiling group
+        :return:
+        """
+        if hasattr(service.code_profiler, "AgentPermissions"):
+            principals = getattr(service.code_profiler, "AgentPermissions")[
+                "Principals"
+            ]
+            potential_principals = [
+                p.data["Fn::GetAtt"][0] for p in principals if isinstance(p, GetAtt)
+            ]
+            if self.task_role.title not in potential_principals:
+                principals.append(GetAtt(self.task_role, "Arn"))
+        else:
+            setattr(
+                service.code_profiler,
+                "AgentPermissions",
+                {
+                    "Principals": [GetAtt(self.task_role, "Arn")],
+                },
+            )
+
+    def set_codeguru_iam_access(self, service):
+        """
+        Method to add IAM permissions via an IAM policy to publish to CodeGuru
+        """
+        self.template.add_resource(
+            PolicyType(
+                "CodeGuruAccess",
+                PolicyName="CodeGuruAccess",
+                PolicyDocument={
+                    "Version": "2012-10-17",
+                    "Statement": [
+                        {
+                            "Effect": "Allow",
+                            "Action": [
+                                "codeguru-profiler:ConfigureAgent",
+                                "codeguru-profiler:PostAgentProfile",
+                            ],
+                            "Resource": GetAtt(service.code_profiler, "Arn"),
+                        }
+                    ],
+                },
+                Roles=[Ref(self.task_role)],
+            )
+        )
+
+    def set_codeguru_profiles_arns(self):
+        if not self.template:
+            LOG.warning(f"No template yet defined for {self.name}")
+            return
+        for service in self.services:
+            if service.code_profiler and isinstance(
+                service.code_profiler, ProfilingGroup
+            ):
+                if (
+                    isinstance(service.container_definition.Environment, Ref)
+                    and service.container_definition.Environment.data["Ref"]
+                    == AWS_NO_VALUE
+                ):
+                    service.container_definition.Environment = []
+                service.container_definition.Environment.append(
+                    Environment(
+                        Name="AWS_CODEGURU_PROFILER_GROUP_ARN",
+                        Value=GetAtt(service.code_profiler, "Arn"),
+                    ),
+                )
+                service.container_definition.Environment.append(
+                    Environment(
+                        Name="AWS_CODEGURU_PROFILER_GROUP_NAME",
+                        Value=Ref(service.code_profiler),
+                    )
+                )
+                if service.code_profiler not in self.template.resources:
+                    self.template.add_resource(service.code_profiler)
+                self.set_codeguru_principals(service)
+                self.set_codeguru_iam_access(service)
+
+    def upload_services_env_files(self, settings):
+        """
+        Method to go over each service and if settings are to upload files to S3, will create objects and update the
+        container definition for env_files accordingly.
+
+        :param ecs_composex.common.settings.ComposeXSettings settings:
+        :return:
+        """
+        if settings.no_upload:
+            return
+        for service in self.services:
+            env_files = []
+            for env_file in service.env_files:
+                with open(env_file, "r") as file_fd:
+                    file_body = file_fd.read()
+                object_name = path.basename(env_file)
+                try:
+                    upload_file(
+                        body=file_body,
+                        bucket_name=settings.bucket_name,
+                        mime="text/plain",
+                        prefix=f"{FILE_PREFIX}/env_files",
+                        file_name=object_name,
+                        settings=settings,
+                    )
+                    LOG.info(f"Successfully uploaded {env_file} to S3")
+                except Exception:
+                    LOG.error(f"Failed to upload env file {object_name}")
+                    raise
+                file_path = Sub(
+                    f"arn:${{{AWS_PARTITION}}}:s3:::{settings.bucket_name}/{FILE_PREFIX}/env_files/{object_name}"
+                )
+                env_files.append(EnvironmentFile(Type="s3", Value=file_path))
+            if not hasattr(service.container_definition, "EnvironmentFiles"):
+                setattr(service.container_definition, "EnvironmentFiles", env_files)
+            else:
+                service.container_definition.EnvironmentFiles += env_files
+            if "S3EnvFilesAccess" not in [
+                policy.PolicyName
+                for policy in self.exec_role.Policies
+                if isinstance(policy.PolicyName, str)
+            ]:
+                self.exec_role.Policies.append(
+                    Policy(
+                        PolicyName="S3EnvFilesAccess",
+                        PolicyDocument={
+                            "Version": "2012-10-17",
+                            "Statement": [
+                                {
+                                    "Action": "s3:GetObject",
+                                    "Effect": "Allow",
+                                    "Resource": Sub(
+                                        f"arn:${{{AWS_PARTITION}}}:s3:::{settings.bucket_name}/*"
+                                    ),
+                                }
+                            ],
+                        },
+                    )
+                )
+
+    def set_repository_credentials(self, settings):
+        """
+        Method to go over each service and identify which ones have credentials to pull the Docker image from a private
+        repository
+
+        :param ecs_composex.common.settings.ComposeXSettings settings:
+        :return:
+        """
+        for service in self.services:
+            if not service.x_repo_credentials:
+                continue
+            if service.x_repo_credentials.startswith("arn:aws"):
+                secret_arn = service.x_repo_credentials
+            elif service.x_repo_credentials.startswith("secrets::"):
+                secret_name = service.x_repo_credentials.split("::")[-1]
+                secret_arn = identify_repo_credentials_secret(
+                    settings, self, secret_name
+                )
+            else:
+                raise ValueError(
+                    "The secret for private repository must be either an ARN or the name of a secret defined in secrets"
+                )
+            setattr(
+                service.container_definition,
+                "RepositoryCredentials",
+                RepositoryCredentials(CredentialsParameter=secret_arn),
+            )
+            self.exec_role.Policies.append(
+                Policy(
+                    PolicyName="AccessToRepoCredentialsSecret",
+                    PolicyDocument={
+                        "Version": "2012-10-17",
+                        "Statement": [
+                            {
+                                "Effect": "Allow",
+                                "Action": ["secretsmanager:GetSecretValue"],
+                                "Sid": "AccessToRepoCredentialsSecret",
+                                "Resource": [secret_arn],
+                            }
+                        ],
+                    },
+                )
+            )
