@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -304,11 +304,7 @@ def merge_config_files(original_content, override_content):
                     )
                 }
             )
-        elif (
-            not keyisset(compose_key, original_content)
-            and keyisset(compose_key, override_content)
-            and isinstance(override_content[compose_key], dict)
-        ):
+        elif not keyisset(compose_key, original_content):
             original_content[compose_key] = override_content[compose_key]
 
 
@@ -417,13 +413,13 @@ class ComposeXSettings(object):
         self.upload = False if self.no_upload else True
         self.create_compute = False if not keyisset(USE_FLEET_T, kwargs) else True
         self.parse_command(kwargs, content)
-        self.compose_content = None
+        self.compose_content = {}
         self.input_file = (
             kwargs[self.input_file_arg] if keyisset(self.input_file_arg, kwargs) else {}
         )
         self.set_content(kwargs, content)
-
         self.set_output_settings(kwargs)
+        self.use_appmesh = keyisset("x-appmesh", self.compose_content)
         self.name = kwargs[self.name_arg]
 
     def set_secrets(self):
@@ -559,7 +555,6 @@ class ComposeXSettings(object):
         :param dict kwargs:
         :param dict content:
         :param bool fully_load:
-        :return:
         """
         if content is None and len(kwargs[self.input_file_arg]) == 1:
             self.compose_content = load_composex_file(kwargs[self.input_file_arg][0])
@@ -677,16 +672,22 @@ class ComposeXSettings(object):
             else:
                 LOG.error(error)
 
-    def set_azs_from_vpc_import(self, public_subnets, app_subnets, storage_subnets):
+    def set_azs_from_vpc_import(
+        self, public_subnets, app_subnets, storage_subnets, session=None
+    ):
         """
         Function to get the list of AZs for a given set of subnets
 
         :param list public_subnets:
         :param list app_subnets:
         :param list storage_subnets:
+        :param session: The Session used to find the EC2 subnets (useful for lookup).
         :return:
         """
-        client = self.session.client("ec2")
+        if session is None:
+            client = self.session.client("ec2")
+        else:
+            client = session.client("ec2")
         try:
             public_r = client.describe_subnets(SubnetIds=public_subnets)["Subnets"]
             app_r = client.describe_subnets(SubnetIds=app_subnets)["Subnets"]
