@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@ from ecs_composex.docdb.docdb_params import (
     DOCDB_PORT,
     DOCDB_SECRET,
 )
+from ecs_composex.vpc.vpc_params import STORAGE_SUBNETS
 from ecs_composex.docdb.docdb_template import create_docdb_template
 
 
@@ -37,6 +38,8 @@ class DocDb(XResource):
     Class to manage DocDB
     """
 
+    subnets_param = STORAGE_SUBNETS
+
     def __init__(self, name, definition, settings):
         """
         Init method
@@ -47,8 +50,10 @@ class DocDb(XResource):
         """
         self.db_secret = None
         self.db_sg = None
+        self.db_subnets_group = None
         super().__init__(name, definition, settings)
         self.arn_attr = DOCDB_SECRET
+        self.set_override_subnets()
 
     def init_outputs(self):
         """
