@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -48,13 +48,6 @@ def init_doc_db_template():
     template = build_template(
         "Root template for DocumentDB for ComposeX", [VPC_ID, STORAGE_SUBNETS]
     )
-    subnet_group = docdb.DBSubnetGroup(
-        DOCDB_SUBNET_GROUP_T,
-        DBSubnetGroupDescription=Sub(f"docdb-subnets-${{{AWS_STACK_NAME}}}"),
-        SubnetIds=Ref(STORAGE_SUBNETS),
-        Tags=Tags(Name=Sub(f"docdb-subnets-${{{AWS_STACK_NAME}}}")),
-    )
-    template.add_resource(subnet_group)
     return template
 
 
@@ -65,7 +58,21 @@ def no_value_if_not_set(props, key, is_bool=False):
         return Ref(AWS_NO_VALUE) if not keypresent(key, props) else props[key]
 
 
-def set_db_cluster(db, secret, sgs):
+def add_parameters_group(db):
+    """
+    Function to create the DBClusterParameterGroup to associate with the cluster
+
+    :param ecs_composex.docdb.docdb_stack.DocDb db:
+    :return: parameter group
+    :rtype: docdb.DBClusterParameterGroup
+    """
+    props = import_record_properties(
+        db.parameters["DBClusterParameterGroup"], docdb.DBClusterParameterGroup
+    )
+    return docdb.DBClusterParameterGroup(f"{db.logical_name}ParametersGroup", **props)
+
+
+def set_db_cluster(template, db, secret, sgs):
     """
     Function to parse and transform yaml definition to Troposphere
 
@@ -73,6 +80,7 @@ def set_db_cluster(db, secret, sgs):
     :param troposphere.secretsmanager.Secret secret:
     :param list<roposphere.ec2.SecurityGroup> sgs:
     """
+    parameter_group = None
     props = import_record_properties(db.properties, docdb.DBCluster)
     if not keypresent("StorageEncrypted", props):
         props["StorageEncrypted"] = True
@@ -85,9 +93,14 @@ def set_db_cluster(db, secret, sgs):
             "MasterUserPassword": Sub(
                 f"{{{{resolve:secretsmanager:${{{secret.title}}}:SecretString:password}}}}"
             ),
+            "DBSubnetGroupName": Ref(db.db_subnets_group),
         }
     )
+    if db.parameters and keyisset("DBClusterParameterGroup", db.parameters):
+        parameter_group = template.add_resource(add_parameters_group(db))
+        props["DBClusterParameterGroupName"] = Ref(parameter_group)
     db.cfn_resource = docdb.DBCluster(db.logical_name, **props)
+    template.add_resource(db.cfn_resource)
 
 
 def add_db_instances(template, db):
@@ -117,15 +130,15 @@ def add_db_instances(template, db):
                 raise KeyError(
                     "You must specify at least the DBInstanceClass", instance.keys()
                 )
-            instance.update(
+            instance_props = import_record_properties(
+                instance, docdb.DBInstance, ignore_missing_required=True
+            )
+            instance_props.update(
                 {
                     "DBClusterIdentifier": Ref(db.cfn_resource),
                     "Tags": Tags(DocDbCluster=Ref(db.cfn_resource)),
                 }
             )
-            instance_props = import_record_properties(
-                instance, docdb.DBInstance, ignore_missing_required=True
-            )
             template.add_resource(
                 docdb.DBInstance(f"{db.logical_name}Instance{count}", **instance_props)
             )
@@ -141,17 +154,33 @@ def create_docdb_template(new_resources, settings):
     :rtype: troposphere.Template
     """
     root_template = init_doc_db_template()
+
     for resource in new_resources:
+
+        resource.db_subnets_group = docdb.DBSubnetGroup(
+            f"{resource.logical_name}SubnetGroup",
+            DBSubnetGroupDescription=Sub(
+                f"docdb-{resource.logical_name}-subnets-${{{AWS_STACK_NAME}}}"
+            ),
+            SubnetIds=Ref(STORAGE_SUBNETS)
+            if not resource.subnets_override
+            else Ref(resource.subnets_override),
+            Tags=Tags(Name=Sub(f"docdb-subnets-${{{AWS_STACK_NAME}}}")),
+        )
         resource.db_sg = SecurityGroup(
             f"{resource.logical_name}Sg",
             GroupDescription=Sub(f"SG for docdb-{resource.logical_name}"),
             GroupName=Sub(f"${{{AWS_STACK_NAME}}}.docdb.{resource.logical_name}"),
             VpcId=Ref(VPC_ID),
         )
+        root_template.add_resource(resource.db_subnets_group)
         root_template.add_resource(resource.db_sg)
         resource.db_secret = add_db_secret(root_template, resource.logical_name)
         set_db_cluster(
-            resource, resource.db_secret, [GetAtt(resource.db_sg, "GroupId")]
+            root_template,
+            resource,
+            resource.db_secret,
+            [GetAtt(resource.db_sg, "GroupId")],
         )
         attach_to_secret_to_resource(
             root_template, resource.cfn_resource, resource.db_secret
@@ -160,6 +189,5 @@ def create_docdb_template(new_resources, settings):
         add_db_instances(root_template, resource)
         resource.init_outputs()
         resource.generate_outputs()
-        root_template.add_resource(resource.cfn_resource)
         root_template.add_output(resource.outputs)
     return root_template
