@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#  Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -138,12 +138,15 @@ def add_service_default_sg(template):
     return sg
 
 
-def add_service_to_map(family):
+def add_service_to_map(family, settings):
     """
     Method to create a new Service into CloudMap to represent the current service and add entry into the registry
     """
     registries = []
-    if not family.service_config.network.ports:
+    if (
+        not family.service_config.network.ports
+        or not family.service_config.network.use_cloudmap
+    ) and not settings.use_appmesh:
         return registries
     sd_service = SdService(
         f"{family.logical_name}DiscoveryService",
@@ -182,13 +185,13 @@ def define_tracking_target_configuration(target_scaling_config, config_key):
     :return:
     """
     settings = {
-        "cpu": {"key": "cpu_target", "property": "ECSServiceAverageCPUUtilization"},
+        "cpu": {"key": "CpuTarget", "property": "ECSServiceAverageCPUUtilization"},
         "memory": {
-            "key": "memory_target",
+            "key": "MemoryTarget",
             "property": "ECSServiceAverageMemoryUtilization",
         },
         "targets": {
-            "key": "tgt_targets_count",
+            "key": "TgtTargetsCount",
             "property": "ALBRequestCountPerTarget",
         },
     }
@@ -199,9 +202,9 @@ def define_tracking_target_configuration(target_scaling_config, config_key):
     )
 
     return applicationautoscaling.TargetTrackingScalingPolicyConfiguration(
-        DisableScaleIn=target_scaling_config["disable_scale_in"],
-        ScaleInCooldown=target_scaling_config["scale_in_cooldown"],
-        ScaleOutCooldown=target_scaling_config["scale_out_cooldown"],
+        DisableScaleIn=target_scaling_config["DisableScaleIn"],
+        ScaleInCooldown=target_scaling_config["ScaleInCooldown"],
+        ScaleOutCooldown=target_scaling_config["ScaleOutCooldown"],
         TargetValue=float(target_scaling_config[settings[config_key]["key"]]),
         PredefinedMetricSpecification=specification,
     )
@@ -211,13 +214,13 @@ def create_scalable_target(family):
     """
     Method to automatically create a scalable target
     """
-    LOG.debug(family.service_config.scaling.range)
-    if family.service_config.scaling.range:
+    LOG.debug(family.service_config.scaling.scaling_range)
+    if family.service_config.scaling.scaling_range:
         family.scalable_target = applicationautoscaling.ScalableTarget(
             ecs_params.SERVICE_SCALING_TARGET,
             template=family.template,
-            MaxCapacity=family.service_config.scaling.range["max"],
-            MinCapacity=family.service_config.scaling.range["min"],
+            MaxCapacity=family.service_config.scaling.scaling_range["max"],
+            MinCapacity=family.service_config.scaling.scaling_range["min"],
             ScalableDimension="ecs:service:DesiredCount",
             ServiceNamespace="ecs",
             RoleARN=Sub(
@@ -233,7 +236,7 @@ def create_scalable_target(family):
             ),
         )
     if family.scalable_target and family.service_config.scaling.target_scaling:
-        if keyisset("cpu_target", family.service_config.scaling.target_scaling):
+        if keyisset("CpuTarget", family.service_config.scaling.target_scaling):
             applicationautoscaling.ScalingPolicy(
                 "ServiceCpuTrackingPolicy",
                 template=family.template,
@@ -244,7 +247,7 @@ def create_scalable_target(family):
                     family.service_config.scaling.target_scaling, "cpu"
                 ),
             )
-        if keyisset("memory_target", family.service_config.scaling.target_scaling):
+        if keyisset("MemoryTarget", family.service_config.scaling.target_scaling):
             applicationautoscaling.ScalingPolicy(
                 "ServiceMemoryTrackingPolicy",
                 template=family.template,
@@ -283,7 +286,7 @@ def generate_service_template_outputs(family):
     )
 
 
-def define_service_ingress(family):
+def define_service_ingress(family, settings):
     """
     Function to define microservice ingress.
 
@@ -291,7 +294,7 @@ def define_service_ingress(family):
     :param family:
     """
     service_lbs = []
-    registries = add_service_to_map(family)
+    registries = add_service_to_map(family, settings)
     if not registries:
         registries = Ref(AWS_NO_VALUE)
     service_attrs = {
@@ -342,11 +345,11 @@ class Service(object):
         self.sgs = []
         self.sg = add_service_default_sg(family.template)
         self.sgs.append(Ref(self.sg))
-        self.generate_service_definition(family)
+        self.generate_service_definition(family, settings)
         create_scalable_target(family)
         generate_service_template_outputs(family)
 
-    def generate_service_definition(self, family):
+    def generate_service_definition(self, family, settings):
         """
         Function to generate the Service definition.
         This is the last step in defining the service, after all other settings have been prepared.
@@ -357,7 +360,7 @@ class Service(object):
             Ref(sg) for sg in self.sgs if not isinstance(sg, (Ref, Sub, If, GetAtt))
         ]
         service_sgs += [sg for sg in self.sgs if isinstance(sg, (Ref, Sub, If, GetAtt))]
-        attrs = define_service_ingress(family)
+        attrs = define_service_ingress(family, settings)
         self.ecs_service = EcsService(
             ecs_params.SERVICE_T,
             template=family.template,
