@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#  Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -296,3 +296,6 @@ def generate_services(settings):
                 ),
             }
         )
+        family.upload_services_env_files(settings)
+        family.set_repository_credentials(settings)
+        family.set_codeguru_profiles_arns()
