@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#  Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ from ecs_composex.common.cfn_params import (
     USE_ONDEMAND,
     USE_ONDEMAND_T,
 )
-from ecs_composex.common.ecs_composex import X_KEY
+from ecs_composex.common.ecs_composex import X_KEY, X_AWS_KEY
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.common.tagging import add_all_tags
 from ecs_composex.compute.compute_params import (
@@ -79,6 +79,7 @@ SUPPORTED_X_MODULE_NAMES = [
     "docdb",
     "events",
     "kinesis",
+    "elasticache",
 ]
 
 SUPPORTED_X_MODULES = [f"{X_KEY}{mod_name}" for mod_name in SUPPORTED_X_MODULE_NAMES]
@@ -92,7 +93,8 @@ EXCLUDED_X_KEYS = [
     f"{X_KEY}cluster",
     f"{X_KEY}efs",
 ]
-TCP_SERVICES = [f"{X_KEY}rds", f"{X_KEY}appmesh", f"{X_KEY}elbv2"]
+TCP_MODES = ["rds", "appmesh", "elbv2", "docdb", "elasticache"]
+TCP_SERVICES = [f"{X_KEY}{mode}" for mode in TCP_MODES]
 
 
 def get_mod_function(module_name, function_name):
@@ -149,18 +151,21 @@ def get_mod_class(module_name):
     return the_class
 
 
-def invoke_x_to_ecs(module, settings, services_stack, resource):
+def invoke_x_to_ecs(module_name, settings, services_stack, resource):
     """
     Function to associate X resources to Services
 
-    :param str module:
     :param ecs_composex.common.settings.ComposeXSettings settings: The compose file content
     :param ecs_composex.ecs.ServicesStack services_stack: root stack for services.
     :param resource: The XStack resource
     :return:
     """
-    composex_key = f"{X_KEY}{module}"
-    ecs_function = get_mod_function(f"{module}.{module}_ecs", f"{module}_to_ecs")
+    if module_name is None:
+        module_name = resource.name
+    composex_key = f"{X_KEY}{module_name}"
+    ecs_function = get_mod_function(
+        f"{module_name}.{module_name}_ecs", f"{module_name}_to_ecs"
+    )
     if ecs_function:
         LOG.debug(ecs_function)
         ecs_function(
@@ -184,11 +189,10 @@ def apply_x_configs_to_ecs(settings, root_stack):
         resource = root_stack.stack_template.resources[resource_name]
         if (
             issubclass(type(resource), ComposeXStack)
-            and resource_name in SUPPORTED_X_MODULE_NAMES
+            and resource.name in SUPPORTED_X_MODULE_NAMES
             and not resource.is_void
         ):
-            module = getattr(resource, "title")
-            invoke_x_to_ecs(module, settings, root_stack, resource)
+            invoke_x_to_ecs(None, settings, root_stack, resource)
 
 
 def apply_x_to_x_configs(root_template, settings):
@@ -203,7 +207,7 @@ def apply_x_to_x_configs(root_template, settings):
         resource = root_template.resources[resource_name]
         if (
             issubclass(type(resource), ComposeXStack)
-            and resource_name in SUPPORTED_X_MODULES
+            and resource.name in SUPPORTED_X_MODULES
             and hasattr(resource, "add_xdependencies")
             and not resource.is_void
         ):
@@ -282,7 +286,11 @@ def add_x_resources(root_template, settings, services_stack, vpc_stack=None):
     Function to add each X resource from the compose file
     """
     for key in settings.compose_content:
-        if key.startswith(X_KEY) and key not in EXCLUDED_X_KEYS:
+        if (
+            key.startswith(X_KEY)
+            and key not in EXCLUDED_X_KEYS
+            and not re.match(X_AWS_KEY, key)
+        ):
             res_type = RES_REGX.sub("", key)
             xclass = get_mod_class(res_type)
             parameters = {ROOT_STACK_NAME_T: Ref(AWS_STACK_NAME)}
