@@ -1,6 +1,6 @@
 #  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -605,6 +605,8 @@ class Elbv2(XResource):
     Class to handle ELBv2 creation and mapping to ECS Services
     """
 
+    subnets_param = APP_SUBNETS
+
     def __init__(self, name, definition, settings):
         if not keyisset("Listeners", definition):
             raise KeyError("You must specify at least one Listener for a LB.", name)
@@ -779,6 +781,11 @@ class Elbv2(XResource):
                 "You defined ingress rules for a NLB. This is invalid. Define ingress rules at the service level."
             )
             return
+        elif not self.parameters or (
+            self.parameters and not keyisset("Ingress", self.parameters)
+        ):
+            LOG.warning(f"You did not define any Ingress rules for ALB {self.name}.")
+            return
         ports = [listener["Port"] for listener in self.definition["Listeners"]]
         ports = set_service_ports(ports)
         self.ingress = Ingress(self.parameters["Ingress"], ports)
