@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -51,13 +51,13 @@ def generate_security_group_props(allowed_source):
     """
     props = {
         "CidrIp": (
-            allowed_source["Ipv4"]
-            if keyisset("Ipv4", allowed_source)
+            allowed_source["IPv4"]
+            if keyisset("IPv4", allowed_source)
             else Ref(AWS_NO_VALUE)
         ),
         "CidrIpv6": (
-            allowed_source["ipv6"]
-            if keyisset("ipv6", allowed_source)
+            allowed_source["IPv6"]
+            if keyisset("IPv6", allowed_source)
             else Ref(AWS_NO_VALUE)
         ),
     }
@@ -139,9 +139,9 @@ class Ingress(object):
     aws_sources_key = "AwsSources"
     ext_sources_key = "ExtSources"
     services_key = "Services"
-    ipv4_key = "Ipv4"
-    ipv6_key = "Ipv6"
-    network_settings = [master_key, "use_cloudmap", "is_public"]
+    ipv4_key = "IPv4"
+    ipv6_key = "IPv6"
+    network_settings = [master_key, "UseCloudmap", "IsPublic"]
 
     def __init__(self, definition, ports):
         """
@@ -283,10 +283,10 @@ class Ingress(object):
             return
 
         for allowed_source in self.ext_sources:
-            if not keyisset("Ipv4", allowed_source) and not keyisset(
-                "Ipv6", allowed_source
+            if not keyisset(self.ipv4_key, allowed_source) and not keyisset(
+                self.ipv6_key, allowed_source
             ):
-                LOG.warning("No IPv4 or IPv6 set. Skipping")
+                LOG.warning(f"No {self.ipv4_key} or {self.ipv6_key} set. Skipping")
                 continue
             props = generate_security_group_props(allowed_source)
             if props:
