@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#  Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -84,7 +84,7 @@ DB_RO_ENDPOINT_ADDRESS = "ReadEndpoint.Address"
 DB_ENDPOINT_PORT_T = "EndpointPort"
 DB_ENDPOINT_PORT_P = Parameter(DB_ENDPOINT_PORT_T, Type="Number")
 
-CLUSTER_SUBNET_GROUP = "ClusterSubnetGroup"
+CLUSTER_SUBNET_GROUP = "RdsSubnetGroup"
 DB_SECRET_T = "RdsDbSecret"
 CLUSTER_T = "AuroraCluster"
 DATABASE_T = "RdsDatabase"
