@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -70,6 +70,8 @@ def import_non_functions(props, prop_name, top_class, properties, set_to_novalue
                     ignore_missing_required=False,
                 )
                 props[prop_name] = top_class.props[prop_name][0](**sub_props)
+            else:
+                props[prop_name] = properties[prop_name]
         except TypeError:
             props[prop_name] = properties[prop_name]
 
