@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -87,6 +87,12 @@ def assign_new_bucket_to_services(bucket, res_root_stack, nested=False):
             add_parameters(
                 target[0].template, [bucket.ref_parameter, bucket.arn_parameter]
             )
+            target[0].stack.Parameters.update(
+                {
+                    bucket.ref_parameter.title: bucket.ref_value,
+                    bucket.arn_parameter.title: bucket.arn_value,
+                }
+            )
             assign_service_permissions_to_bucket(
                 bucket,
                 target[0],
