@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#  Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -30,6 +30,8 @@ from troposphere.ec2 import (
     DHCPOptions,
     VPCDHCPOptionsAssociation,
     FlowLog,
+    PrefixList,
+    Entry,
 )
 from troposphere.iam import Role, Policy
 from troposphere.logs import LogGroup
@@ -141,6 +143,19 @@ def add_vpc_core(template, vpc_cidr):
         ),
         Metadata=metadata,
     )
+    template.add_resource(
+        PrefixList(
+            "VpcPrefixList",
+            AddressFamily="IPv4",
+            Entries=[
+                Entry(
+                    Cidr=vpc_cidr, Description=Sub(f"Primary CIDR for ${{{vpc.title}}}")
+                )
+            ],
+            MaxEntries=5,
+            PrefixListName=Ref(vpc),
+        )
+    )
     igw = InternetGateway(IGW_T, template=template)
     VPCGatewayAttachment(
         "VPCGatewayAttachement",
